pub struct Priority(/* private fields */);Expand description
Represents the priority of an enqueued rebuild job. The job queue is sorted based on priority and time, so the lower this number is, the more prioritized the job is. It’s a little backwards, but hey.
There are some utility functions on the type for accessing default values for well-defined use cases. These map to constants in the same namespace as this type, and you can use either one.
use rebuilderd_common::api::v1::Priority;
assert_eq!(Priority::from(1), Priority::default());
assert_eq!(Priority::from(2), Priority::retry());
assert_eq!(Priority::from(0), Priority::manual());You can also set a completely custom priority. This is mostly useful for external API calls that orchestrate rebuilds.
use rebuilderd_common::api::v1::Priority;
let custom = Priority::from(10);
assert_eq!(custom, Priority::from(10));
Implementations