Module utils

Module utils 

Constants

ZSTD_CHUNK_SIZE
ZSTD_MAGIC

Functions

is_zstd_compressed
Checks if a block of data is compressed with the zstd algorithm.
load_or_create
secs_to_human
zstd_compress
Compresses a block of data using the zstd algorithm in asynchronous chunks, yielding in between each one.
zstd_decompress
Decompresses a block of data using the zstd algorithm in asynchronous chunks, yielding in between each one.