zstd_decompress

Function zstd_decompress 

pub async fn zstd_decompress(data: &[u8]) -> Result<Vec<u8>>
Decompresses a block of data using the zstd algorithm in asynchronous chunks, yielding in between each one.

Chunks are sized to fit within zstd’s default internal buffer size.