Constants
Functions
- is_
zstd_ compressed - Checks if a block of data is compressed with the zstd algorithm.
- load_
or_ create - secs_
to_ human - zstd_
compress - Compresses a block of data using the zstd algorithm in asynchronous chunks, yielding in between each one.
- zstd_
decompress - Decompresses a block of data using the zstd algorithm in asynchronous chunks, yielding in between each one.